<?php declare(strict_types=1);

namespace Infomaker\Imengine\CropData;

use Infomaker\Imengine\CropData\Interfaces\CropResizeDataInterface;
use Infomaker\Imengine\Helpers\ImengineHelper;

/**
 * Class CropResizeData
 *
 * @package Infomaker\Imengine
 */
class CropResizeData implements CropResizeDataInterface
{
    private $cropWidth;
    private $cropHeight;
    private $width;
    private $height;
    private $cropX = 0.0;
    private $cropY = 0.0;

    /**
     * CropResizeData constructor.
     *
     * @param float $cropWidth  Width of the soft crop, as percent of the original image.
     * @param float $cropHeight Height of the soft crop, as percentage of the original image.
     */
    public function __construct(float $cropWidth, float $cropHeight)
    {
        $this->cropWidth  = ImengineHelper::formatNumberToImengineFloat($cropWidth);
        $this->cropHeight = ImengineHelper::formatNumberToImengineFloat($cropHeight);
    }

    /**
     * @return int Width of the resulting image.
     */
    public function getWidth(): int
    {
        return $this->width;
    }

    /**
     * @param mixed $width Width of the resulting image.
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setWidth(int $width): CropResizeData
    {
        $this->width = $width;

        return $this;
    }

    /**
     * @return int Height of the resulting image.
     */
    public function getHeight(): int
    {
        return $this->height;
    }

    /**
     * @param mixed $height Height of the resulting image.
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setHeight(int $height): CropResizeData
    {
        $this->height = $height;

        return $this;
    }

    /**
     * @return float Horisontal start position for the soft crop, as percentage of the original image from the left.
     */
    public function getCropX(): float
    {
        return $this->cropX;
    }

    /**
     * @param float $cropX Horisontal start position for the soft crop, as percentage of the original image from the left.
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setCropX(float $cropX): CropResizeData
    {
        $this->cropX = $cropX;

        return $this;
    }

    /**
     * @return float Vertical start position for the soft crop, as percentage of the original image from the top.
     */
    public function getCropY(): float
    {
        return $this->cropY;
    }

    /**
     * @param float $cropY Vertical start position for the soft crop, as percentage of the original image from the top.
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setCropY(float $cropY): CropResizeData
    {
        $this->cropY = $cropY;

        return $this;
    }

    /**
     * @return float Width of the soft crop, as percent of the original image.
     */
    public function getCropWidth(): float
    {
        return $this->cropWidth;
    }

    /**
     * @return float Height of the soft crop, as percent of the original image.
     */
    public function getCropHeight(): float
    {
        return $this->cropHeight;
    }
}
