<?php declare(strict_types=1);

namespace Infomaker\Imengine\CropData;

use Infomaker\Imengine\CropData\Interfaces\NewsPilotCropDataInterface;

/**
 * Class NpCropData
 *
 * @package Infomaker\Imengine
 */
class NewsPilotCropData implements NewsPilotCropDataInterface
{
    private $width;
    private $height;
    private $cropX = 0.0;
    private $cropY = 0.0;
    private $zoom = 0.5;

    /**
     * NpCropDataInterface constructor.
     *
     * @param int $width
     * @param int $height
     */
    public function __construct(int $width, int $height)
    {
        $this->width  = $width;
        $this->height = $height;
    }

    /**
     * @return int Width of the resulting image.
     */
    public function getWidth(): int
    {
        return $this->width;
    }

    /**
     * @return int Height of the resulting image.
     */
    public function getHeight(): int
    {
        return $this->height;
    }

    /**
     * @return float Horisontal start position for the soft crop, as percentage of the original image from the left.
     */
    public function getCropX(): float
    {
        return $this->cropX;
    }

    /**
     * @return float Vertical start position for the soft crop, as percentage of the original image from the top.
     */
    public function getCropY(): float
    {
        return $this->cropY;
    }

    /**
     * @return float Zoom of soft crop.
     */
    public function getZoom(): float
    {
        return $this->zoom;
    }

    /**
     * @param mixed $zoom Zoom of soft crop.
     *
     * @return \Infomaker\Imengine\CropData\NewsPilotCropData
     */
    public function setZoom(float $zoom): NewsPilotCropData
    {
        $this->zoom = $zoom;

        return $this;
    }

    /**
     * @param mixed $cropX Horisontal start position for the soft crop, as percentage of the original image from the left.
     *
     * @return \Infomaker\Imengine\CropData\NewsPilotCropData
     */
    public function setCropX(float $cropX): NewsPilotCropData
    {
        $this->cropX = $cropX;

        return $this;
    }

    /**
     * @param float $cropY Vertical start position for the soft crop, as percentage of the original image from the top.
     *
     * @return \Infomaker\Imengine\CropData\NewsPilotCropData
     */
    public function setCropY(float $cropY): NewsPilotCropData
    {
        $this->cropY = $cropY;

        return $this;
    }
}
